Estimate the distribution of final outbreak sizes by group using stochastic simulations of multi-group model
getFinalSizeDist.RdEstimate the distribution of final outbreak sizes by group using stochastic simulations of multi-group model
Arguments
- n
the number of simulations to run
- transmrates
matrix of group-to-group (column-to-row) transmission rates
- recoveryrate
inverse of mean infectious period
- popsize
the population size of each group
- initR
initial number of each group already infected and removed for each simulation (included in final size result); if a matrix, row i is used for simulation i
- initI
initial number of each group infectious for each simulation; if a matrix, row i is used for simulation i
- initV
initial number of each group immune due to vaccination or prior-outbreak infection for each simulation (not included in final size result); if a matrix, row i is used for simulation i